#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity
version:              1.1.1.0
visibility:           public
id:                   genvalidity-1.1.1.0-EO6XtMlPXRQDbf2BOJHMvp
key:                  genvalidity-1.1.1.0-EO6XtMlPXRQDbf2BOJHMvp
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Testing utilities for the validity library
description:
    Note: There are companion instance packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-aeson genvalidity-aeson>

    * <https://hackage.haskell.org/package/genvalidity-bytestring genvalidity-bytestring>

    * <https://hackage.haskell.org/package/genvalidity-containers genvalidity-containers>

    * <https://hackage.haskell.org/package/genvalidity-path genvalidity-path>

    * <https://hackage.haskell.org/package/genvalidity-scientific genvalidity-scientific>

    * <https://hackage.haskell.org/package/genvalidity-text genvalidity-text>

    * <https://hackage.haskell.org/package/genvalidity-time genvalidity-time>

    * <https://hackage.haskell.org/package/genvalidity-unordered-containers genvalidity-unordered-containers>

    * <https://hackage.haskell.org/package/genvalidity-uuid genvalidity-uuid>

    * <https://hackage.haskell.org/package/genvalidity-vector genvalidity-vector>

category:             Testing
abi:                  3016bb3c9ddc54a2283c22e43fb557ab
exposed:              True
exposed-modules:      Data.GenValidity Data.GenValidity.Utils
hidden-modules:       Paths_genvalidity
import-dirs:          /usr/lib/ghc-9.6.6/site-local/genvalidity-1.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/genvalidity-1.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/genvalidity-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity
hs-libraries:         HSgenvalidity-1.1.1.0-EO6XtMlPXRQDbf2BOJHMvp
depends:
    QuickCheck-2.15.0.1-7YGuUScDosvJpuKkMIUiat base-4.18.2.1
    random-1.2.1.3-GfiOoTkiJ8dHrTrBUL8yXz
    validity-0.12.1.0-5k4s85m8SW4EBgaw5yGZHe

haddock-interfaces:   /usr/share/doc/haskell-genvalidity/html/genvalidity.haddock
haddock-html:         /usr/share/doc/haskell-genvalidity/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

